@@ -1,9 +1,7 @@
 #define APT_BUILD_CONF_PATH "/etc/apt/apt-build.conf"
 #define APT_BUILD_STRING_ENV "APT_BUILD_WRAPPER"
 
-#define GPP_PATH "/usr/bin/g++"
-#define GCC_PATH "/usr/bin/gcc"
-#define MAKE_PATH "/usr/bin/make"
+#define LIBDIR "/usr/lib/apt-build/"
 
 #define MAKE_ARGC 0
 #define GCC_ARGC 2
@@ -18,4 +16,3 @@ struct apt_build_args
   char *options;
   char *make_options;
 };
-
